package com.ruoyi.zongzhi.mapper;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcYqFl;

/**
 * 舆情分类Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
public interface TcYqFlMapper 
{
    /**
     * 查询舆情分类
     * 
     * @param id 舆情分类主键
     * @return 舆情分类
     */
    public TcYqFl selectTcYqFlById(Long id);

    /**
     * 查询舆情分类列表
     * 
     * @param tcYqFl 舆情分类
     * @return 舆情分类集合
     */
    public List<TcYqFl> selectTcYqFlList(TcYqFl tcYqFl);

    /**
     * 新增舆情分类
     * 
     * @param tcYqFl 舆情分类
     * @return 结果
     */
    public int insertTcYqFl(TcYqFl tcYqFl);

    /**
     * 修改舆情分类
     * 
     * @param tcYqFl 舆情分类
     * @return 结果
     */
    public int updateTcYqFl(TcYqFl tcYqFl);

    /**
     * 删除舆情分类
     * 
     * @param id 舆情分类主键
     * @return 结果
     */
    public int deleteTcYqFlById(Long id);

    /**
     * 批量删除舆情分类
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcYqFlByIds(Long[] ids);
}
